@@ -10,8 +10,8 @@
 #include "config.h"
 #include <string.h>
 
-#define BONOBO_EXPLICIT_TRANSLATION_DOMAIN GETTEXT_PACKAGE
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n-lib.h>    
+
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-moniker.h>
 #include <bonobo/bonobo-moniker-util.h>
@@ -106,7 +106,6 @@ Bonobo_Moniker
 bonobo_moniker_get_parent (BonoboMoniker     *moniker,
 			   CORBA_Environment *opt_ev)
 {
-	CORBA_Environment ev, *my_ev;
 	Bonobo_Moniker rval;
 
 	bonobo_return_val_if_fail (BONOBO_IS_MONIKER (moniker),
@@ -115,17 +114,8 @@ bonobo_moniker_get_parent (BonoboMoniker     *moniker,
 	if (moniker->priv->parent == CORBA_OBJECT_NIL)
 		return CORBA_OBJECT_NIL;
 
-	if (!opt_ev) {
-		CORBA_exception_init (&ev);
-		my_ev = &ev;
-	} else
-		my_ev = opt_ev;
-
 	rval = bonobo_object_dup_ref (moniker->priv->parent, opt_ev);
 
-	if (!opt_ev)
-		CORBA_exception_free (&ev);
-
 	return rval;
 }
 
@@ -349,7 +339,7 @@ impl_resolve (PortableServer_Servant       servant,
 
 	if (!BONOBO_EX (ev) && retval == CORBA_OBJECT_NIL) {
 		bonobo_exception_general_error_set (
-			ev, NULL, _("Failed to resolve, or extend '%s"),
+			ev, NULL, _("Failed to resolve, or extend '%s'"),
 			bonobo_moniker_get_name_full (moniker));
 	}
 
