@@ -6,7 +6,7 @@
 G_BEGIN_DECLS
 
 #define BONOBO_TYPE_STREAM_CACHE        (bonobo_stream_cache_get_type ())
-#define BONOBO_STREAM_CACHE_TYPE        BONOBO_TYPE_STREAM_CACHE // deprecated, you should use BONOBO_TYPE_STREAM_CACHE
+#define BONOBO_STREAM_CACHE_TYPE        BONOBO_TYPE_STREAM_CACHE /* deprecated, you should use BONOBO_TYPE_STREAM_CACHE */
 #define BONOBO_STREAM_CACHE(o)          (G_TYPE_CHECK_INSTANCE_CAST ((o), BONOBO_TYPE_STREAM_CACHE, BonoboStreamCache))
 #define BONOBO_STREAM_CACHE_CLASS(k)    (G_TYPE_CHECK_CLASS_CAST((k), BONOBO_TYPE_STREAM_CACHE, BonoboStreamCacheClass))
 #define BONOBO_IS_STREAM_CACHE(o)       (G_TYPE_CHECK_INSTANCE_TYPE ((o), BONOBO_TYPE_STREAM_CACHE))
